<?php
/*
 * @wordpress-plugin
 * Plugin Name:       hockeydata LOS
 * Plugin URI:        https://apidocs.hockeydata.net/plugins/wordpress/
 * Description:       hockeydata Live.Online Statistics
 * Version:           1.1.2
 * Author:            hockeydata
 * Author URI:        http://www.hockeydata.net/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       hockeydata_los
 * Domain Path:       /languages
*/
define( 'HD_LOS_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );

function los_init() {

	include( HD_LOS_PLUGIN_PATH . 'inc/helpers.php' );
	include( HD_LOS_PLUGIN_PATH . 'inc/widget-printers.php' );
	include( HD_LOS_PLUGIN_PATH . 'inc/widget-options-helpers.php' );

	add_action( 'widgets_init', 'los_load_widgets' );
	add_action( 'widgets_init', 'los_add_shortcodes' );
	add_action( 'plugins_loaded', 'los_load_textdomain' );
	add_action( 'wp_enqueue_scripts', 'los_register_styles' );
	add_action( 'wp_head', 'los_add_custom_css', 100 );

	if ( is_admin() ) {

		add_action( 'admin_print_scripts', 'los_admin_register_scripts' );
		add_action( 'admin_print_styles', 'los_admin_register_styles' );
		add_action( 'admin_init', 'los_register_settings' );
		add_action( 'admin_menu', 'los_admin_menu' );

	}

}

function los_load_widgets() {

    include( HD_LOS_PLUGIN_PATH . 'widgets/game-full-report.php' );
	include( HD_LOS_PLUGIN_PATH . 'widgets/game-slider.php' );
	include( HD_LOS_PLUGIN_PATH . 'widgets/leaders.php' );
	include( HD_LOS_PLUGIN_PATH . 'widgets/player-full-page.php' );
	include( HD_LOS_PLUGIN_PATH . 'widgets/schedule.php' );
	include( HD_LOS_PLUGIN_PATH . 'widgets/standings.php' );
	include( HD_LOS_PLUGIN_PATH . 'widgets/team-full-page.php' );
	include( HD_LOS_PLUGIN_PATH . 'widgets/team-stats.php' );

	register_widget( 'LOS_Widget_GameFullReport' );
    register_widget( 'LOS_Widget_GameSlider' );
	register_widget( 'LOS_Widget_Leaders' );
	register_widget( 'LOS_Widget_PlayerFullPage' );
	register_widget( 'LOS_Widget_Schedule' );
	register_widget( 'LOS_Widget_Standings' );
	register_widget( 'LOS_Widget_TeamFullPage' );
	register_widget( 'LOS_Widget_TeamStats' );

}

function los_load_textdomain() {

	load_plugin_textdomain( 'hockeydata_los', false, basename( dirname( __FILE__ ) ) . '/languages' );

}

function los_register_settings() {

	register_setting( 'los_general_options', 'los_api_key' );
	register_setting( 'los_general_options', 'los_sport' );
	register_setting( 'los_general_options', 'los_language' );
	register_setting( 'los_general_options', 'los_page_game_report' );
	register_setting( 'los_general_options', 'los_page_player_details' );
	register_setting( 'los_general_options', 'los_page_team_details' );

	register_setting( 'los_styling_options', 'los_template' );
	register_setting( 'los_styling_options', 'los_css_color_0' );
	register_setting( 'los_styling_options', 'los_css_color_1' );
	register_setting( 'los_styling_options', 'los_css_color_2' );
	register_setting( 'los_styling_options', 'los_css_color_3' );
	register_setting( 'los_styling_options', 'los_css_color_4' );
	register_setting( 'los_styling_options', 'los_css_color_5' );
	register_setting( 'los_styling_options', 'los_css_color_6' );
	register_setting( 'los_styling_options', 'los_css_color_7' );
	register_setting( 'los_styling_options', 'los_css_color_8' );
	register_setting( 'los_styling_options', 'los_css_color_9' );

}

function los_register_styles() {

	$template = get_option( 'los_template' );

	if ( $template ) {

		wp_register_style( 'los-template', 'https://api.hockeydata.net/css/?los_template_' . esc_attr( $template ) );
		wp_enqueue_style( 'los-template' );

	}

}

function los_add_custom_css() {

	$custom_css = los_get_custom_css();

	if ( $custom_css ) {

		echo '<style type="text/css">' . $custom_css . '</style>';

	}

}

function los_add_shortcodes() {

	add_shortcode( 'los-game-full-report', 'los_widget_game_full_report' );
	add_shortcode( 'los-game-slider', 'los_widget_game_slider' );
	add_shortcode( 'los-leaders', 'los_widget_leaders' );
	add_shortcode( 'los-player-full-page', 'los_widget_player_full_page' );
	add_shortcode( 'los-schedule', 'los_widget_schedule' );
	add_shortcode( 'los-standings', 'los_widget_standings' );
	add_shortcode( 'los-team-full-page', 'los_widget_team_full_page' );
	add_shortcode( 'los-team-stats', 'los_widget_team_stats' );

}

function los_admin_load_page( $page ) {

	include( 'inc/admin-header.php' );
	include( 'pages/' . $page . '.php' );
	include( 'inc/admin-footer.php' );

}

function los_admin_register_scripts() {

	wp_register_script( 'los-admin-script', plugins_url( '/js/los-admin.js', __FILE__ ), array( 'wp-color-picker' ) );

	wp_enqueue_script( 'los-admin-script' );

}

function los_admin_register_styles() {

	wp_register_style( 'los-admin-style', plugins_url( '/css/los-admin.css', __FILE__ ) );

	wp_enqueue_style( 'wp-color-picker' );
	wp_enqueue_style( 'los-admin-style' );

}

function los_admin_menu() {

	add_options_page( 'hockeydata Live.Online Statistics', 'LOS', 'administrator', 'hockeydata_los_settings', 'los_admin_menu_settings' );

}

function los_admin_menu_settings() {

	los_admin_load_page( 'settings' );

}

los_init();